# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dynamic/gw/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/dynamic/gw/gateway.proto\x12\x18\x62ilibili.dynamic.gateway\x1a\x19google/protobuf/any.proto\"/\n\x07\x41\x64Param\x12\x10\n\x08\x61\x64_extra\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\xa1\x02\n\x0e\x41\x64\x64itionCommon\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12:\n\x06\x62utton\x18\x07 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x33\n\x05style\x18\t \x01(\x0e\x32$.bilibili.dynamic.gateway.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbd\x01\n\x0e\x41\x64\x64itionEsport\x12\x34\n\x05style\x18\x01 \x01(\x0e\x32%.bilibili.dynamic.gateway.EspaceStyle\x12L\n\x14\x61\x64\x64ition_esport_moba\x18\x02 \x01(\x0b\x32,.bilibili.dynamic.gateway.AdditionEsportMobaH\x00\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x11\n\tcard_type\x18\x04 \x01(\tB\x06\n\x04item\"\xc5\x02\n\x12\x41\x64\x64itionEsportMoba\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x37\n\nmatch_team\x18\x03 \x03(\x0b\x32#.bilibili.dynamic.gateway.MatchTeam\x12W\n\x1b\x61\x64\x64ition_esport_moba_status\x18\x04 \x01(\x0b\x32\x32.bilibili.dynamic.gateway.AdditionEsportMobaStatus\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12:\n\x06\x62utton\x18\x06 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\tsub_title\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x11\n\tcard_type\x18\x0b \x01(\t\"\xbf\x01\n\x18\x41\x64\x64itionEsportMobaStatus\x12`\n addition_esport_moba_status_desc\x18\x01 \x03(\x0b\x32\x36.bilibili.dynamic.gateway.AdditionEsportMobaStatusDesc\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"Q\n\x1c\x41\x64\x64itionEsportMobaStatusDesc\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x13\n\x0bnight_color\x18\x03 \x01(\t\"\x9f\x01\n\rAdditionGoods\x12\x11\n\trcmd_desc\x18\x01 \x01(\t\x12\x38\n\x0bgoods_items\x18\x02 \x03(\x0b\x32#.bilibili.dynamic.gateway.GoodsItem\x12\x11\n\tcard_type\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\x05\"\xa0\x02\n\nAdditionUP\x12\r\n\x05title\x18\x01 \x01(\t\x12<\n\x0b\x64\x65sc_text_1\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.HighlightText\x12\x13\n\x0b\x64\x65sc_text_2\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12:\n\x06\x62utton\x18\x05 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\tcard_type\x18\x06 \x01(\t\x12\x15\n\rreserve_total\x18\x07 \x01(\x03\x12=\n\x08\x61\x63t_skin\x18\x08 \x01(\x0b\x32+.bilibili.dynamic.gateway.AdditionalActSkin\"\xad\x01\n\x0b\x41\x64\x64itionUgc\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08\x64uration\x18\x07 \x01(\t\x12\x11\n\tline_feed\x18\x08 \x01(\x08\x12\x11\n\tcard_type\x18\t \x01(\t\"b\n\x0c\x41\x64\x64itionVote\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0e\n\x06text_1\x18\x03 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\x8c\x05\n\rAdditionVote2\x12\x46\n\x12\x61\x64\x64ition_vote_type\x18\x01 \x01(\x0e\x32*.bilibili.dynamic.gateway.AdditionVoteType\x12\x0f\n\x07vote_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\x12\x11\n\topen_text\x18\x06 \x01(\t\x12\x12\n\nclose_text\x18\x07 \x01(\t\x12\x12\n\nvoted_text\x18\x08 \x01(\t\x12:\n\x05state\x18\t \x01(\x0e\x32+.bilibili.dynamic.gateway.AdditionVoteState\x12H\n\x12\x61\x64\x64ition_vote_word\x18\n \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionVoteWordH\x00\x12\x46\n\x11\x61\x64\x64ition_vote_pic\x18\x0b \x01(\x0b\x32).bilibili.dynamic.gateway.AdditionVotePicH\x00\x12N\n\x15\x61\x64\x64ition_vote_defaule\x18\x0c \x01(\x0b\x32-.bilibili.dynamic.gateway.AdditionVoteDefauleH\x00\x12\x10\n\x08\x62iz_type\x18\r \x01(\x05\x12\r\n\x05total\x18\x0e \x01(\x03\x12\x11\n\tcard_type\x18\x0f \x01(\t\x12\x0c\n\x04tips\x18\x10 \x01(\t\x12\x0b\n\x03uri\x18\x11 \x01(\t\x12\x10\n\x08is_voted\x18\x12 \x01(\x08\x12\x12\n\nchoice_cnt\x18\x13 \x01(\x05\x12\x1c\n\x14\x64\x65\x66\x61ule_select_share\x18\x14 \x01(\x08\x42\x06\n\x04item\"$\n\x13\x41\x64\x64itionVoteDefaule\x12\r\n\x05\x63over\x18\x01 \x03(\t\"N\n\x0f\x41\x64\x64itionVotePic\x12;\n\x04item\x18\x01 \x03(\x0b\x32-.bilibili.dynamic.gateway.AdditionVotePicItem\"\x8c\x01\n\x13\x41\x64\x64itionVotePicItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\r\n\x05title\x18\x06 \x01(\t\x12\x15\n\ris_max_option\x18\x07 \x01(\x08\"P\n\x10\x41\x64\x64itionVoteWord\x12<\n\x04item\x18\x01 \x03(\x0b\x32..bilibili.dynamic.gateway.AdditionVoteWordItem\"~\n\x14\x41\x64\x64itionVoteWordItem\x12\x0f\n\x07opt_idx\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07is_vote\x18\x03 \x01(\x08\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0f\n\x07persent\x18\x05 \x01(\x01\x12\x15\n\ris_max_option\x18\x06 \x01(\x08\"I\n\x11\x41\x64\x64itionalActSkin\x12\x0c\n\x04svga\x18\x01 \x01(\t\x12\x12\n\nlast_image\x18\x02 \x01(\t\x12\x12\n\nplay_times\x18\x03 \x01(\x03\"\xad\x03\n\x10\x41\x64\x64itionalButton\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.AddButtonType\x12\x43\n\njump_style\x18\x02 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12@\n\x07uncheck\x18\x04 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12>\n\x05\x63heck\x18\x05 \x01(\x0b\x32/.bilibili.dynamic.gateway.AdditionalButtonStyle\x12@\n\x06status\x18\x06 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\x12G\n\nclick_type\x18\x07 \x01(\x0e\x32\x33.bilibili.dynamic.gateway.AdditionalButtonClickType\"\\\n\x1b\x41\x64\x64itionalButtonInteractive\x12\x0e\n\x06popups\x18\x01 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x02 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\x85\x02\n\x15\x41\x64\x64itionalButtonStyle\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12J\n\x0binteractive\x18\x03 \x01(\x0b\x32\x35.bilibili.dynamic.gateway.AdditionalButtonInteractive\x12<\n\x08\x62g_style\x18\x04 \x01(\x0e\x32*.bilibili.dynamic.gateway.AddButtonBgStyle\x12\r\n\x05toast\x18\x05 \x01(\t\x12\x37\n\x07\x64isable\x18\x06 \x01(\x0e\x32&.bilibili.dynamic.gateway.DisableState\"\x8d\x02\n\rAdditionalPGC\x12\x11\n\thead_text\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_1\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65sc_text_2\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12:\n\x06\x62utton\x18\x07 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x11\n\thead_icon\x18\x08 \x01(\t\x12\x33\n\x05style\x18\t \x01(\x0e\x32$.bilibili.dynamic.gateway.ImageStyle\x12\x0c\n\x04type\x18\n \x01(\t\"\x9e\x01\n\x10\x43\x61rdVideoDynList\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"d\n\x13\x43\x61rdVideoFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.bilibili.dynamic.gateway.FollowListItem\"\xa0\x02\n\x0f\x43\x61rdVideoUpList\x12\r\n\x05title\x18\x01 \x01(\t\x12\x32\n\x04list\x18\x02 \x03(\x0b\x32$.bilibili.dynamic.gateway.UpListItem\x12\x11\n\tfootprint\x18\x03 \x01(\t\x12\x15\n\rshow_live_num\x18\x04 \x01(\x05\x12=\n\nmore_label\x18\x05 \x01(\x0b\x32).bilibili.dynamic.gateway.UpListMoreLabel\x12\x14\n\x0ctitle_switch\x18\x06 \x01(\x05\x12\x17\n\x0fshow_more_label\x18\x07 \x01(\x08\x12\x18\n\x10show_in_personal\x18\x08 \x01(\x08\x12\x18\n\x10show_more_button\x18\t \x01(\x08\"G\n\x0b\x43mtShowItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"P\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x12\n\nnumber_str\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"r\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x32\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32%.bilibili.dynamic.gateway.DecoCardFan\"\xa6\x02\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".bilibili.dynamic.gateway.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x37\n\nemoji_type\x18\x04 \x01(\x0e\x32#.bilibili.dynamic.gateway.EmojiType\x12\x12\n\ngoods_type\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x11\n\ticon_name\x18\x07 \x01(\t\x12\x0b\n\x03rid\x18\x08 \x01(\t\x12\x38\n\x05goods\x18\t \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleDescGoods\x12\x11\n\torig_text\x18\n \x01(\t\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"`\n\x1c\x44ynAdditionCommonFollowReply\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\"\x81\x01\n\x1a\x44ynAdditionCommonFollowReq\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.dynamic.gateway.AdditionalButtonStatus\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x11\n\tcard_type\x18\x03 \x01(\t\"\xb7\x01\n\x13\x44ynAllPersonalReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x34\n\x08relation\x18\x05 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"\x86\x02\n\x11\x44ynAllPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"\xf5\x01\n\x0b\x44ynAllReply\x12;\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicList\x12:\n\x07up_list\x18\x02 \x01(\x0b\x32).bilibili.dynamic.gateway.CardVideoUpList\x12\x37\n\ntopic_list\x18\x03 \x01(\x0b\x32#.bilibili.dynamic.gateway.TopicList\x12\x34\n\x08unfollow\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.Unfollow\"\xb9\x03\n\tDynAllReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x37\n\x0crefresh_type\x18\x04 \x01(\x0e\x32!.bilibili.dynamic.gateway.Refresh\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12>\n\x0ercmd_ups_param\x18\x08 \x01(\x0b\x32&.bilibili.dynamic.gateway.RcmdUPsParam\x12\x33\n\x08\x61\x64_param\x18\t \x01(\x0b\x32!.bilibili.dynamic.gateway.AdParam\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0c\n\x04\x66rom\x18\x0b \x01(\t\x12\x39\n\x0bplayer_args\x18\x0c \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"N\n\x12\x44ynAllUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"E\n\x0e\x44ynDetailReply\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\"\xb2\x01\n\rDynDetailsReq\x12\x13\n\x0b\x64ynamic_ids\x18\x01 \x01(\t\x12=\n\rplayurl_param\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x03 \x01(\x05\x12\x39\n\x0bplayer_args\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"G\n\x10\x44ynFakeCardReply\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\"!\n\x0e\x44ynFakeCardReq\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\xe1\x01\n\x19\x44ynMixUpListViewMoreReply\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.dynamic.gateway.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\x12\x36\n\nsort_types\x18\x03 \x03(\x0b\x32\".bilibili.dynamic.gateway.SortType\x12\x1c\n\x14show_more_sort_types\x18\x04 \x01(\x08\x12\x19\n\x11\x64\x65\x66\x61ult_sort_type\x18\x05 \x01(\x05\",\n\x17\x44ynMixUpListViewMoreReq\x12\x11\n\tsort_type\x18\x01 \x01(\x05\"N\n\x16\x44ynRcmdUpExchangeReply\x12\x34\n\x08unfollow\x18\x01 \x01(\x0b\x32\".bilibili.dynamic.gateway.Unfollow\"D\n\x14\x44ynRcmdUpExchangeReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\tdislikeTs\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"|\n\x0b\x44ynThumbReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0b\n\x03rid\x18\x04 \x01(\t\x12\x31\n\x04type\x18\x05 \x01(\x0e\x32#.bilibili.dynamic.gateway.ThumbType\"\xb9\x01\n\x15\x44ynVideoPersonalReply\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\x12\x34\n\x08relation\x18\x05 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"\x88\x02\n\x13\x44ynVideoPersonalReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x12\n\nis_preload\x18\x04 \x01(\x05\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x11\n\tfootprint\x18\x07 \x01(\t\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"\xdd\x01\n\rDynVideoReply\x12@\n\x0c\x64ynamic_list\x18\x01 \x01(\x0b\x32*.bilibili.dynamic.gateway.CardVideoDynList\x12@\n\rvideo_up_list\x18\x02 \x01(\x0b\x32).bilibili.dynamic.gateway.CardVideoUpList\x12H\n\x11video_follow_list\x18\x03 \x01(\x0b\x32-.bilibili.dynamic.gateway.CardVideoFollowList\"\xb2\x02\n\x0b\x44ynVideoReq\x12\x17\n\x0fupdate_baseline\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x37\n\x0crefresh_type\x18\x04 \x01(\x0e\x32!.bilibili.dynamic.gateway.Refresh\x12=\n\rplayurl_param\x18\x05 \x01(\x0b\x32&.bilibili.dynamic.gateway.PlayurlParam\x12\x17\n\x0f\x61ssist_baseline\x18\x06 \x01(\t\x12\x12\n\nlocal_time\x18\x07 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x08 \x01(\t\x12\x39\n\x0bplayer_args\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.PlayerArgs\"P\n\x14\x44ynVideoUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\x12\x11\n\tfootprint\x18\x03 \x01(\t\"T\n\x0c\x44ynVoteReply\x12\x35\n\x04item\x18\x01 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionVote2\x12\r\n\x05toast\x18\x02 \x01(\t\"\x85\x01\n\nDynVoteReq\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\r\n\x05votes\x18\x02 \x03(\x03\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32$.bilibili.dynamic.gateway.VoteStatus\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\r\n\x05share\x18\x05 \x01(\x08\"\xf8\x01\n\x0b\x44ynamicItem\x12\x38\n\tcard_type\x18\x01 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x38\n\titem_type\x18\x02 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x31\n\x07modules\x18\x03 \x03(\x0b\x32 .bilibili.dynamic.gateway.Module\x12\x30\n\x06\x65xtend\x18\x04 \x01(\x0b\x32 .bilibili.dynamic.gateway.Extend\x12\x10\n\x08has_fold\x18\x05 \x01(\x05\"\x99\x01\n\x0b\x44ynamicList\x12\x33\n\x04list\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x03\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x08\"\xe3\x01\n\rExtInfoCommon\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynExtendType\x12\x12\n\nsub_module\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_text\x18\x07 \x01(\t\x12\x12\n\naction_url\x18\x08 \x01(\t\x12\x0b\n\x03rid\x18\t \x01(\x03\x12\x15\n\ris_show_light\x18\n \x01(\x08\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"A\n\nExtInfoOGV\x12\x33\n\x08info_ogv\x18\x01 \x03(\x0b\x32!.bilibili.dynamic.gateway.InfoOGV\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"\x98\x04\n\x06\x45xtend\x12\x12\n\ndyn_id_str\x18\x01 \x01(\t\x12\x13\n\x0b\x62usiness_id\x18\x02 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x03 \x01(\t\x12\x11\n\torig_name\x18\x04 \x01(\t\x12\x14\n\x0corig_img_url\x18\x05 \x01(\t\x12\x38\n\torig_desc\x18\x06 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x33\n\x04\x64\x65sc\x18\x07 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12<\n\rorig_dyn_type\x18\x08 \x01(\x0e\x32%.bilibili.dynamic.gateway.DynamicType\x12\x12\n\nshare_type\x18\t \x01(\t\x12\x13\n\x0bshare_scene\x18\n \x01(\t\x12\x15\n\ris_fast_share\x18\x0b \x01(\x08\x12\x0e\n\x06r_type\x18\x0c \x01(\x05\x12\x10\n\x08\x64yn_type\x18\r \x01(\x03\x12\x0b\n\x03uid\x18\x0e \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x0f \x01(\t\x12,\n\x0esource_content\x18\x10 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\torig_face\x18\x11 \x01(\t\x12\x34\n\x05reply\x18\x12 \x01(\x0b\x32%.bilibili.dynamic.gateway.ExtendReply\"V\n\x0b\x45xtendReply\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x03(\x0b\x32*.bilibili.dynamic.gateway.ExtendReplyParam\".\n\x10\x45xtendReplyParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9f\x01\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12/\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1f.bilibili.dynamic.gateway.NewEP\x12\x11\n\tsub_title\x18\x06 \x01(\t\x12\x0b\n\x03pos\x18\x07 \x01(\x03\"\x82\x02\n\tGoodsItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x11\n\tjump_desc\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x62rief\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\t\x12\x0f\n\x07item_id\x18\t \x01(\x03\x12\x12\n\nschema_url\x18\n \x01(\t\x12\x17\n\x0fopen_white_list\x18\x0b \x03(\t\x12\x13\n\x0buser_web_v2\x18\x0c \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\r \x01(\t\"_\n\rHighlightText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12@\n\ntext_style\x18\x02 \x01(\x0e\x32,.bilibili.dynamic.gateway.HighlightTextStyle\"G\n\x07InfoOGV\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nsub_module\x18\x04 \x01(\t\"\xb8\x01\n\x0fInteractionItem\x12:\n\ticon_type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.LocalIconType\x12\x33\n\x04\x64\x65sc\x18\x02 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\ndynamic_id\x18\x04 \x01(\t\x12\x13\n\x0b\x63omment_mid\x18\x06 \x01(\x03\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"W\n\x08LikeInfo\x12:\n\tanimation\x18\x01 \x01(\x0b\x32\'.bilibili.dynamic.gateway.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x08\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"c\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x37\n\nlive_state\x18\x03 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\"X\n\tMatchTeam\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\x12\x13\n\x0bnight_color\x18\x05 \x01(\t\"\x8b\x01\n\x0cMdlDynApplet\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x11\n\tsub_title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\r\n\x05label\x18\x08 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\t \x01(\t\"\xe3\x05\n\rMdlDynArchive\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x37\n\nmedia_type\x18\t \x01(\x0e\x32#.bilibili.dynamic.gateway.MediaType\x12\x36\n\tdimension\x18\n \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x33\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x08\x12\x32\n\x05stype\x18\r \x01(\x0e\x32#.bilibili.dynamic.gateway.VideoType\x12\r\n\x05isPGC\x18\x0e \x01(\x08\x12\x11\n\tinlineURL\x18\x0f \x01(\t\x12\x11\n\tEpisodeId\x18\x10 \x01(\x03\x12\x0f\n\x07SubType\x18\x11 \x01(\x05\x12\x13\n\x0bPgcSeasonId\x18\x12 \x01(\x03\x12\x11\n\tplay_icon\x18\x13 \x01(\t\x12\x10\n\x08\x64uration\x18\x14 \x01(\x03\x12\x10\n\x08jump_url\x18\x15 \x01(\t\x12\x12\n\nis_preview\x18\x16 \x01(\x08\x12<\n\x0e\x62\x61\x64ge_category\x18\x17 \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x12\n\nis_feature\x18\x18 \x01(\x08\x12;\n\x0creserve_type\x18\x19 \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\x12\x0c\n\x04\x62vid\x18\x1a \x01(\t\x12\x0c\n\x04view\x18\x1b \x01(\x05\"x\n\rMdlDynArticle\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0e\n\x06\x63overs\x18\x05 \x03(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x12\n\ntemplateID\x18\x07 \x01(\x05\"\xf6\x01\n\x0cMdlDynCommon\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0f\n\x07\x62izType\x18\x07 \x01(\x05\x12\x10\n\x08sketchID\x18\x08 \x01(\x03\x12\x39\n\x05style\x18\t \x01(\x0e\x32*.bilibili.dynamic.gateway.MdlDynCommonType\x12\x33\n\x05\x62\x61\x64ge\x18\n \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\"\xa4\x01\n\x0fMdlDynCourBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"\xa3\x01\n\x10MdlDynCourSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x11\n\tplay_icon\x18\x07 \x01(\t\"^\n\nMdlDynDraw\x12\x37\n\x05items\x18\x01 \x03(\x0b\x32(.bilibili.dynamic.gateway.MdlDynDrawItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\"\x81\x01\n\x0eMdlDynDrawItem\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x35\n\x04tags\x18\x05 \x03(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynDrawTag\"\x85\x01\n\rMdlDynDrawTag\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.bilibili.dynamic.gateway.MdlDynDrawTagType\x12\x39\n\x04item\x18\x02 \x01(\x0b\x32+.bilibili.dynamic.gateway.MdlDynDrawTagItem\"\xb5\x01\n\x11MdlDynDrawTagItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x03\x12\t\n\x01y\x18\x04 \x01(\x03\x12\x13\n\x0borientation\x18\x05 \x01(\x05\x12\x0e\n\x06source\x18\x06 \x01(\x05\x12\x0f\n\x07item_id\x18\x07 \x01(\x03\x12\x0b\n\x03mid\x18\x08 \x01(\x03\x12\x0b\n\x03tid\x18\t \x01(\x03\x12\x0b\n\x03poi\x18\n \x01(\t\x12\x12\n\nschema_url\x18\x0b \x01(\t\"S\n\rMdlDynForward\x12\x33\n\x04item\x18\x01 \x01(\x0b\x32%.bilibili.dynamic.gateway.DynamicItem\x12\r\n\x05rtype\x18\x02 \x01(\x05\"\x99\x02\n\nMdlDynLive\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_label\x18\x05 \x01(\t\x12\x14\n\x0c\x63over_label2\x18\x06 \x01(\t\x12\x37\n\nlive_state\x18\x07 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12\x33\n\x05\x62\x61\x64ge\x18\x08 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12;\n\x0creserve_type\x18\t \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\"^\n\x0eMdlDynLiveRcmd\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12;\n\x0creserve_type\x18\x02 \x01(\x0e\x32%.bilibili.dynamic.gateway.ReserveType\"\xa4\x01\n\x0fMdlDynMedialist\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_type\x18\x06 \x01(\x05\x12\x33\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\"r\n\x0bMdlDynMusic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05up_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0e\n\x06label1\x18\x06 \x01(\t\x12\r\n\x05upper\x18\x07 \x01(\t\"\x86\x05\n\tMdlDynPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x37\n\nmedia_type\x18\x0b \x01(\x0e\x32#.bilibili.dynamic.gateway.MediaType\x12\x38\n\x08sub_type\x18\x0c \x01(\x0e\x32&.bilibili.dynamic.gateway.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x36\n\tdimension\x18\x0e \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x33\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x08\x12\x33\n\x06season\x18\x11 \x01(\x0b\x32#.bilibili.dynamic.gateway.PGCSeason\x12\x11\n\tplay_icon\x18\x12 \x01(\t\x12\x10\n\x08\x64uration\x18\x13 \x01(\x03\x12\x10\n\x08jump_url\x18\x14 \x01(\t\x12<\n\x0e\x62\x61\x64ge_category\x18\x15 \x03(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x12\n\nis_feature\x18\x16 \x01(\x08\"\xaf\x01\n\x12MdlDynSubscription\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08\x61\x64_title\x18\x06 \x01(\t\x12\x33\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.VideoBadge\x12\x0c\n\x04tips\x18\x08 \x01(\t\"\xf1\x01\n\x15MdlDynSubscriptionNew\x12\x43\n\x05style\x18\x01 \x01(\x0e\x32\x34.bilibili.dynamic.gateway.MdlDynSubscriptionNewStyle\x12H\n\x10\x64yn_subscription\x18\x02 \x01(\x0b\x32,.bilibili.dynamic.gateway.MdlDynSubscriptionH\x00\x12\x41\n\rdyn_live_rcmd\x18\x03 \x01(\x0b\x32(.bilibili.dynamic.gateway.MdlDynLiveRcmdH\x00\x42\x06\n\x04item\"\xc8\x02\n\x0fMdlDynUGCSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x11\n\tinlineURL\x18\x08 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\t \x01(\x08\x12\x11\n\tplay_icon\x18\n \x01(\t\x12\x0c\n\x04\x61vid\x18\x0b \x01(\x03\x12\x0b\n\x03\x63id\x18\x0c \x01(\x03\x12\x36\n\tdimension\x18\r \x01(\x0b\x32#.bilibili.dynamic.gateway.Dimension\x12\x10\n\x08\x64uration\x18\x0e \x01(\x03\x12\x10\n\x08jump_url\x18\x0f \x01(\t\"\xcb\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12>\n\tlive_info\x18\x04 \x01(\x0b\x32+.bilibili.dynamic.gateway.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12:\n\x08official\x18\x07 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x08 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x34\n\x08relation\x18\t \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x90\x0b\n\x06Module\x12<\n\x0bmodule_type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynModuleType\x12?\n\rmodule_author\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleAuthorH\x00\x12\x41\n\x0emodule_dispute\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleDisputeH\x00\x12;\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleDescH\x00\x12\x41\n\x0emodule_dynamic\x18\x05 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleDynamicH\x00\x12\x43\n\x0fmodule_likeUser\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.ModuleLikeUserH\x00\x12?\n\rmodule_extend\x18\x07 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleExtendH\x00\x12G\n\x11module_additional\x18\x08 \x01(\x0b\x32*.bilibili.dynamic.gateway.ModuleAdditionalH\x00\x12;\n\x0bmodule_stat\x18\t \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStatH\x00\x12;\n\x0bmodule_fold\x18\n \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleFoldH\x00\x12\x41\n\x0emodule_comment\x18\x0b \x01(\x0b\x32\'.bilibili.dynamic.gateway.ModuleCommentH\x00\x12I\n\x12module_interaction\x18\x0c \x01(\x0b\x32+.bilibili.dynamic.gateway.ModuleInteractionH\x00\x12N\n\x15module_author_forward\x18\r \x01(\x0b\x32-.bilibili.dynamic.gateway.ModuleAuthorForwardH\x00\x12\x37\n\tmodule_ad\x18\x0e \x01(\x0b\x32\".bilibili.dynamic.gateway.ModuleAdH\x00\x12?\n\rmodule_banner\x18\x0f \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleBannerH\x00\x12\x44\n\x10module_item_null\x18\x10 \x01(\x0b\x32(.bilibili.dynamic.gateway.ModuleItemNullH\x00\x12\x46\n\x11module_share_info\x18\x11 \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleShareInfoH\x00\x12\x45\n\x10module_recommend\x18\x12 \x01(\x0b\x32).bilibili.dynamic.gateway.ModuleRecommendH\x00\x12\x39\n\nmodule_top\x18\x13 \x01(\x0b\x32#.bilibili.dynamic.gateway.ModuleTopH\x00\x12?\n\rmodule_buttom\x18\x14 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleButtomH\x00\x12\x43\n\x13module_stat_forward\x18\x15 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStatH\x00\x42\r\n\x0bmodule_item\"w\n\x08ModuleAd\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12=\n\rmodule_author\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ModuleAuthor\"\xa5\x04\n\x10ModuleAdditional\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.AdditionalType\x12\x36\n\x03pgc\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionalPGCH\x00\x12\x38\n\x05goods\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionGoodsH\x00\x12\x36\n\x04vote\x18\x04 \x01(\x0b\x32&.bilibili.dynamic.gateway.AdditionVoteH\x00\x12:\n\x06\x63ommon\x18\x05 \x01(\x0b\x32(.bilibili.dynamic.gateway.AdditionCommonH\x00\x12:\n\x06\x65sport\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.AdditionEsportH\x00\x12\x38\n\x05vote2\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.AdditionVote2H\x00\x12\x34\n\x03ugc\x18\t \x01(\x0b\x32%.bilibili.dynamic.gateway.AdditionUgcH\x00\x12\x32\n\x02up\x18\n \x01(\x0b\x32$.bilibili.dynamic.gateway.AdditionUPH\x00\x12\x0b\n\x03rid\x18\x07 \x01(\x03\x42\x06\n\x04item\"\xf6\x03\n\x0cModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x32\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\".bilibili.dynamic.gateway.UserInfo\x12=\n\rdecorate_card\x18\x04 \x01(\x0b\x32&.bilibili.dynamic.gateway.DecorateCard\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x39\n\x07tp_list\x18\x06 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\x12\x43\n\nbadge_type\x18\x07 \x01(\x0e\x32/.bilibili.dynamic.gateway.ModuleAuthorBadgeType\x12G\n\x0c\x62\x61\x64ge_button\x18\x08 \x01(\x0b\x32\x31.bilibili.dynamic.gateway.ModuleAuthorBadgeButton\x12\x0e\n\x06\x61ttend\x18\t \x01(\x05\x12\x34\n\x08relation\x18\n \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\x12\x30\n\x06weight\x18\x0b \x01(\x0b\x32 .bilibili.dynamic.gateway.Weight\"Q\n\x17ModuleAuthorBadgeButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\"\xa4\x02\n\x13ModuleAuthorForward\x12\x41\n\x05title\x18\x01 \x03(\x0b\x32\x32.bilibili.dynamic.gateway.ModuleAuthorForwardTitle\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x04 \x01(\t\x12\x13\n\x0bshow_follow\x18\x05 \x01(\x08\x12\x10\n\x08\x66\x61\x63\x65_url\x18\x06 \x01(\t\x12\x34\n\x08relation\x18\x07 \x01(\x0b\x32\".bilibili.dynamic.gateway.Relation\x12\x39\n\x07tp_list\x18\x08 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\"5\n\x18ModuleAuthorForwardTitle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc7\x01\n\x0cModuleBanner\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.bilibili.dynamic.gateway.ModuleBannerType\x12:\n\x04user\x18\x03 \x01(\x0b\x32*.bilibili.dynamic.gateway.ModuleBannerUserH\x00\x12\x14\n\x0c\x64islike_text\x18\x04 \x01(\t\x12\x14\n\x0c\x64islike_icon\x18\x05 \x01(\tB\x06\n\x04item\"P\n\x10ModuleBannerUser\x12<\n\x04list\x18\x01 \x03(\x0b\x32..bilibili.dynamic.gateway.ModuleBannerUserItem\"\xbc\x02\n\x14ModuleBannerUserItem\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x37\n\nlive_state\x18\x04 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12:\n\x08official\x18\x05 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x06 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\r\n\x05label\x18\x07 \x01(\t\x12:\n\x06\x62utton\x18\x08 \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\x12\x0b\n\x03uri\x18\t \x01(\t\"I\n\x0cModuleButtom\x12\x39\n\x0bmodule_stat\x18\x01 \x01(\x0b\x32$.bilibili.dynamic.gateway.ModuleStat\"K\n\rModuleComment\x12:\n\x0b\x63mtShowItem\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.CmtShowItem\"a\n\nModuleDesc\x12\x33\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32%.bilibili.dynamic.gateway.Description\x12\x10\n\x08jump_uri\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xb9\x01\n\x0fModuleDescGoods\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x12\n\nschema_url\x18\x03 \x01(\t\x12\x0f\n\x07item_id\x18\x04 \x01(\x03\x12\x17\n\x0fopen_white_list\x18\x05 \x03(\t\x12\x13\n\x0buser_web_v2\x18\x06 \x01(\x08\x12\x0f\n\x07\x61\x64_mark\x18\x07 \x01(\t\x12\x1b\n\x13schema_package_name\x18\x08 \x01(\t\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xf7\x08\n\rModuleDynamic\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.bilibili.dynamic.gateway.ModuleDynamicType\x12>\n\x0b\x64yn_archive\x18\x02 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynArchiveH\x00\x12\x36\n\x07\x64yn_pgc\x18\x03 \x01(\x0b\x32#.bilibili.dynamic.gateway.MdlDynPGCH\x00\x12\x45\n\x0f\x64yn_cour_season\x18\x04 \x01(\x0b\x32*.bilibili.dynamic.gateway.MdlDynCourSeasonH\x00\x12\x43\n\x0e\x64yn_cour_batch\x18\x05 \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynCourBatchH\x00\x12>\n\x0b\x64yn_forward\x18\x06 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynForwardH\x00\x12\x38\n\x08\x64yn_draw\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.MdlDynDrawH\x00\x12>\n\x0b\x64yn_article\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.MdlDynArticleH\x00\x12:\n\tdyn_music\x18\t \x01(\x0b\x32%.bilibili.dynamic.gateway.MdlDynMusicH\x00\x12<\n\ndyn_common\x18\n \x01(\x0b\x32&.bilibili.dynamic.gateway.MdlDynCommonH\x00\x12?\n\x0f\x64yn_common_live\x18\x0b \x01(\x0b\x32$.bilibili.dynamic.gateway.MdlDynLiveH\x00\x12\x42\n\rdyn_medialist\x18\x0c \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynMedialistH\x00\x12<\n\ndyn_applet\x18\r \x01(\x0b\x32&.bilibili.dynamic.gateway.MdlDynAppletH\x00\x12H\n\x10\x64yn_subscription\x18\x0e \x01(\x0b\x32,.bilibili.dynamic.gateway.MdlDynSubscriptionH\x00\x12\x41\n\rdyn_live_rcmd\x18\x0f \x01(\x0b\x32(.bilibili.dynamic.gateway.MdlDynLiveRcmdH\x00\x12\x43\n\x0e\x64yn_ugc_season\x18\x10 \x01(\x0b\x32).bilibili.dynamic.gateway.MdlDynUGCSeasonH\x00\x12O\n\x14\x64yn_subscription_new\x18\x11 \x01(\x0b\x32/.bilibili.dynamic.gateway.MdlDynSubscriptionNewH\x00\x42\r\n\x0bmodule_item\"W\n\x0cModuleExtend\x12:\n\x06\x65xtend\x18\x01 \x03(\x0b\x32*.bilibili.dynamic.gateway.ModuleExtendItem\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xd3\x03\n\x10ModuleExtendItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.dynamic.gateway.DynExtendType\x12@\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.ExtInfoTopicH\x00\x12<\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoLBSH\x00\x12<\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoHotH\x00\x12>\n\rext_info_game\x18\x05 \x01(\x0b\x32%.bilibili.dynamic.gateway.ExtInfoGameH\x00\x12\x42\n\x0f\x65xt_info_common\x18\x06 \x01(\x0b\x32\'.bilibili.dynamic.gateway.ExtInfoCommonH\x00\x12<\n\x0c\x65xt_info_ogv\x18\x07 \x01(\x0b\x32$.bilibili.dynamic.gateway.ExtInfoOGVH\x00\x42\x08\n\x06\x65xtend\"\x9b\x01\n\nModuleFold\x12\x35\n\tfold_type\x18\x01 \x01(\x0e\x32\".bilibili.dynamic.gateway.FoldType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x36\n\nfold_users\x18\x04 \x03(\x0b\x32\".bilibili.dynamic.gateway.UserInfo\"X\n\x11ModuleInteraction\x12\x43\n\x10interaction_item\x18\x01 \x03(\x0b\x32).bilibili.dynamic.gateway.InteractionItem\",\n\x0eModuleItemNull\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"^\n\x0eModuleLikeUser\x12\x36\n\nlike_users\x18\x01 \x03(\x0b\x32\".bilibili.dynamic.gateway.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x86\x01\n\x0fModuleRecommend\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\x12 \n\x02\x61\x64\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\"\x90\x01\n\x0fModuleShareInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12>\n\x0eshare_channels\x18\x02 \x03(\x0b\x32&.bilibili.dynamic.gateway.ShareChannel\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\"\xdd\x01\n\nModuleStat\x12\x0e\n\x06repost\x18\x01 \x01(\x03\x12\x0c\n\x04like\x18\x02 \x01(\x03\x12\r\n\x05reply\x18\x03 \x01(\x03\x12\x35\n\tlike_info\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\x12\x11\n\treply_url\x18\x07 \x01(\t\x12\x17\n\x0fno_comment_text\x18\x08 \x01(\t\x12\x17\n\x0fno_forward_text\x18\t \x01(\t\"F\n\tModuleTop\x12\x39\n\x07tp_list\x18\x01 \x03(\x0b\x32(.bilibili.dynamic.gateway.ThreePointItem\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"J\n\nPlayerArgs\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x12\n\nforce_host\x18\x04 \x01(\x03\"[\n\x0cPlayurlParam\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"\"\n\x0cRcmdUPsParam\x12\x12\n\ndislike_ts\x18\x01 \x01(\x03\"{\n\x08Relation\x12\x38\n\x06status\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"<\n\x0cShareChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\"5\n\x08SortType\x12\x11\n\tsort_type\x18\x01 \x01(\x05\x12\x16\n\x0esort_type_name\x18\x02 \x01(\t\"\xc2\x01\n\x13ThreePointAttention\x12\x16\n\x0e\x61ttention_icon\x18\x01 \x01(\t\x12\x16\n\x0e\x61ttention_text\x18\x02 \x01(\t\x12\x1a\n\x12not_attention_icon\x18\x03 \x01(\t\x12\x1a\n\x12not_attention_text\x18\x04 \x01(\t\x12\x43\n\x06status\x18\x05 \x01(\x0e\x32\x33.bilibili.dynamic.gateway.ThreePointAttentionStatus\"\xe2\x01\n\x12ThreePointAutoPlay\x12\x11\n\topen_icon\x18\x01 \x01(\t\x12\x11\n\topen_text\x18\x02 \x01(\t\x12\x12\n\nclose_icon\x18\x03 \x01(\t\x12\x12\n\nclose_text\x18\x04 \x01(\t\x12\x14\n\x0copen_text_v2\x18\x05 \x01(\t\x12\x15\n\rclose_text_v2\x18\x06 \x01(\t\x12\x11\n\tonly_icon\x18\x07 \x01(\t\x12\x11\n\tonly_text\x18\x08 \x01(\t\x12\x14\n\x0copen_icon_v2\x18\t \x01(\t\x12\x15\n\rclose_icon_v2\x18\n \x01(\t\"I\n\x11ThreePointDefault\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"0\n\x11ThreePointDislike\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x12ThreePointFavorite\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x14\n\x0cis_favourite\x18\x04 \x01(\x08\x12\x13\n\x0b\x63\x61ncel_icon\x18\x05 \x01(\t\x12\x14\n\x0c\x63\x61ncel_title\x18\x06 \x01(\t\"\x91\x04\n\x0eThreePointItem\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.bilibili.dynamic.gateway.ThreePointType\x12>\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32+.bilibili.dynamic.gateway.ThreePointDefaultH\x00\x12\x43\n\x0b\x61uto_player\x18\x03 \x01(\x0b\x32,.bilibili.dynamic.gateway.ThreePointAutoPlayH\x00\x12:\n\x05share\x18\x04 \x01(\x0b\x32).bilibili.dynamic.gateway.ThreePointShareH\x00\x12\x42\n\tattention\x18\x05 \x01(\x0b\x32-.bilibili.dynamic.gateway.ThreePointAttentionH\x00\x12\x38\n\x04wait\x18\x06 \x01(\x0b\x32(.bilibili.dynamic.gateway.ThreePointWaitH\x00\x12>\n\x07\x64islike\x18\x07 \x01(\x0b\x32+.bilibili.dynamic.gateway.ThreePointDislikeH\x00\x12@\n\x08\x66\x61vorite\x18\x08 \x01(\x0b\x32,.bilibili.dynamic.gateway.ThreePointFavoriteH\x00\x42\x06\n\x04item\"\x87\x01\n\x0fThreePointShare\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x41\n\x07\x63hannel\x18\x03 \x03(\x0b\x32\x30.bilibili.dynamic.gateway.ThreePointShareChannel\x12\x14\n\x0c\x63hannel_name\x18\x04 \x01(\t\"5\n\x16ThreePointShareChannel\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"~\n\x0eThreePointWait\x12\x15\n\raddition_icon\x18\x01 \x01(\t\x12\x15\n\raddition_text\x18\x02 \x01(\t\x12\x18\n\x10no_addition_icon\x18\x03 \x01(\t\x12\x18\n\x10no_addition_text\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"<\n\x0bTopicButton\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08jump_uri\x18\x03 \x01(\t\"\xd3\x01\n\tTopicList\x12\r\n\x05title\x18\x01 \x01(\t\x12@\n\x0ftopic_list_item\x18\x02 \x03(\x0b\x32\'.bilibili.dynamic.gateway.TopicListItem\x12\x39\n\nact_button\x18\x03 \x01(\x0b\x32%.bilibili.dynamic.gateway.TopicButton\x12:\n\x0bmore_button\x18\x04 \x01(\x0b\x32%.bilibili.dynamic.gateway.TopicButton\"q\n\rTopicListItem\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_title\x18\x02 \x01(\t\x12\x10\n\x08topic_id\x18\x03 \x01(\x03\x12\x12\n\ntopic_name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x0b\n\x03pos\x18\x06 \x01(\x03\"d\n\x08Unfollow\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\x04list\x18\x02 \x03(\x0b\x32*.bilibili.dynamic.gateway.UnfollowUserItem\x12\x0f\n\x07TrackId\x18\x03 \x01(\t\"\xda\x02\n\x10UnfollowUserItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x05\x12\x37\n\nlive_state\x18\x06 \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12:\n\x08official\x18\x07 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x08 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x0c\n\x04sign\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12:\n\x06\x62utton\x18\x0b \x01(\x0b\x32*.bilibili.dynamic.gateway.AdditionalButton\"\x9e\x03\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x08\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03pos\x18\x05 \x01(\x03\x12>\n\x0euser_item_type\x18\x06 \x01(\x0e\x32&.bilibili.dynamic.gateway.UserItemType\x12\x42\n\x11\x64isplay_style_day\x18\x07 \x01(\x0b\x32\'.bilibili.dynamic.gateway.UserItemStyle\x12\x44\n\x13\x64isplay_style_night\x18\x08 \x01(\x0b\x32\'.bilibili.dynamic.gateway.UserItemStyle\x12\x10\n\x08style_id\x18\t \x01(\x03\x12\x37\n\nlive_state\x18\n \x01(\x0e\x32#.bilibili.dynamic.gateway.LiveState\x12\x11\n\tseparator\x18\x0b \x01(\x08\x12\x0b\n\x03uri\x18\x0c \x01(\t\x12\x11\n\tis_recall\x18\r \x01(\x08\"-\n\x0fUpListMoreLabel\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xce\x02\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12:\n\x08official\x18\x04 \x01(\x0b\x32(.bilibili.dynamic.gateway.OfficialVerify\x12.\n\x03vip\x18\x05 \x01(\x0b\x32!.bilibili.dynamic.gateway.VipInfo\x12\x30\n\x04live\x18\x06 \x01(\x0b\x32\".bilibili.dynamic.gateway.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x36\n\x07pendant\x18\x08 \x01(\x0b\x32%.bilibili.dynamic.gateway.UserPendant\x12\x36\n\tnameplate\x18\t \x01(\x0b\x32#.bilibili.dynamic.gateway.Nameplate\"~\n\rUserItemStyle\x12\x11\n\trect_text\x18\x01 \x01(\t\x12\x17\n\x0frect_text_color\x18\x02 \x01(\t\x12\x11\n\trect_icon\x18\x03 \x01(\t\x12\x15\n\rrect_bg_color\x18\x04 \x01(\t\x12\x17\n\x0fouter_animation\x18\x05 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xe0\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08\x62g_alpha\x18\t \x01(\x05\x12\x16\n\x0e\x62g_alpha_night\x18\n \x01(\x05\"\xb2\x01\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x31\n\x05label\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.gateway.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t\"Z\n\x06Weight\x12\r\n\x05title\x18\x01 \x01(\t\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.bilibili.dynamic.gateway.WeightItem\x12\x0c\n\x04icon\x18\x03 \x01(\t\"/\n\x0cWeightButton\x12\x10\n\x08jump_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"6\n\rWeightDislike\x12\x16\n\x0e\x66\x65\x65\x64_back_type\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\xbe\x01\n\nWeightItem\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.bilibili.dynamic.gateway.WeightType\x12\x38\n\x06\x62utton\x18\x02 \x01(\x0b\x32&.bilibili.dynamic.gateway.WeightButtonH\x00\x12:\n\x07\x64islike\x18\x03 \x01(\x0b\x32\'.bilibili.dynamic.gateway.WeightDislikeH\x00\x42\x06\n\x04item*2\n\x10\x41\x64\x64\x42uttonBgStyle\x12\x08\n\x04\x66ill\x10\x00\x12\n\n\x06stroke\x10\x01\x12\x08\n\x04gray\x10\x02*8\n\rAddButtonType\x12\x0b\n\x07\x62t_none\x10\x00\x12\x0b\n\x07\x62t_jump\x10\x01\x12\r\n\tbt_button\x10\x02*n\n\x11\x41\x64\x64itionVoteState\x12\x1c\n\x18\x61\x64\x64ition_vote_state_none\x10\x00\x12\x1c\n\x18\x61\x64\x64ition_vote_state_open\x10\x01\x12\x1d\n\x19\x61\x64\x64ition_vote_state_close\x10\x02*\x88\x01\n\x10\x41\x64\x64itionVoteType\x12\x1b\n\x17\x61\x64\x64ition_vote_type_none\x10\x00\x12\x1b\n\x17\x61\x64\x64ition_vote_type_word\x10\x01\x12\x1a\n\x16\x61\x64\x64ition_vote_type_pic\x10\x02\x12\x1e\n\x1a\x61\x64\x64ition_vote_type_default\x10\x03*9\n\x19\x41\x64\x64itionalButtonClickType\x12\x0e\n\nclick_none\x10\x00\x12\x0c\n\x08\x63lick_up\x10\x01*:\n\x16\x41\x64\x64itionalButtonStatus\x12\x08\n\x04none\x10\x00\x12\x0b\n\x07uncheck\x10\x01\x12\t\n\x05\x63heck\x10\x02*\x85\x02\n\x0e\x41\x64\x64itionalType\x12\x13\n\x0f\x61\x64\x64itional_none\x10\x00\x12\x17\n\x13\x61\x64\x64itional_type_pgc\x10\x01\x12\x19\n\x15\x61\x64\x64itional_type_goods\x10\x02\x12\x18\n\x14\x61\x64\x64itional_type_vote\x10\x03\x12\x1a\n\x16\x61\x64\x64itional_type_common\x10\x04\x12\x1a\n\x16\x61\x64\x64itional_type_esport\x10\x05\x12\x1b\n\x17\x61\x64\x64itional_type_up_rcmd\x10\x06\x12\x17\n\x13\x61\x64\x64itional_type_ugc\x10\x07\x12\"\n\x1e\x61\x64\x64itional_type_up_reservation\x10\x08*\xf9\x02\n\x08\x44\x65scType\x12\x12\n\x0e\x64\x65sc_type_none\x10\x00\x12\x12\n\x0e\x64\x65sc_type_text\x10\x01\x12\x12\n\x0e\x64\x65sc_type_aite\x10\x02\x12\x15\n\x11\x64\x65sc_type_lottery\x10\x03\x12\x12\n\x0e\x64\x65sc_type_vote\x10\x04\x12\x13\n\x0f\x64\x65sc_type_topic\x10\x05\x12\x13\n\x0f\x64\x65sc_type_goods\x10\x06\x12\x10\n\x0c\x64\x65sc_type_bv\x10\x07\x12\x10\n\x0c\x64\x65sc_type_av\x10\x08\x12\x13\n\x0f\x64\x65sc_type_emoji\x10\t\x12\x12\n\x0e\x64\x65sc_type_user\x10\n\x12\x10\n\x0c\x64\x65sc_type_cv\x10\x0b\x12\x10\n\x0c\x64\x65sc_type_vc\x10\x0c\x12\x11\n\rdesc_type_web\x10\r\x12\x14\n\x10\x64\x65sc_type_taobao\x10\x0e\x12\x12\n\x0e\x64\x65sc_type_mail\x10\x0f\x12\x18\n\x14\x64\x65sc_type_ogv_season\x10\x10\x12\x14\n\x10\x64\x65sc_type_ogv_ep\x10\x11*\'\n\x0c\x44isableState\x12\r\n\thighlight\x10\x00\x12\x08\n\x04gary\x10\x01*\xe5\x01\n\rDynExtendType\x12\x15\n\x11\x64yn_ext_type_none\x10\x00\x12\x16\n\x12\x64yn_ext_type_topic\x10\x01\x12\x14\n\x10\x64yn_ext_type_lbs\x10\x02\x12\x14\n\x10\x64yn_ext_type_hot\x10\x03\x12\x15\n\x11\x64yn_ext_type_game\x10\x04\x12\x17\n\x13\x64yn_ext_type_common\x10\x05\x12\x18\n\x14\x64yn_ext_type_biliCut\x10\x06\x12\x14\n\x10\x64yn_ext_type_ogv\x10\x07\x12\x19\n\x15\x64yn_ext_type_auto_ogv\x10\x08*\xc9\x03\n\rDynModuleType\x12\x0f\n\x0bmodule_none\x10\x00\x12\x11\n\rmodule_author\x10\x01\x12\x12\n\x0emodule_dispute\x10\x02\x12\x0f\n\x0bmodule_desc\x10\x03\x12\x12\n\x0emodule_dynamic\x10\x04\x12\x12\n\x0emodule_forward\x10\x05\x12\x13\n\x0fmodule_likeUser\x10\x06\x12\x11\n\rmodule_extend\x10\x07\x12\x15\n\x11module_additional\x10\x08\x12\x0f\n\x0bmodule_stat\x10\t\x12\x0f\n\x0bmodule_fold\x10\n\x12\x12\n\x0emodule_comment\x10\x0b\x12\x16\n\x12module_interaction\x10\x0c\x12\x19\n\x15module_author_forward\x10\r\x12\r\n\tmodule_ad\x10\x0e\x12\x11\n\rmodule_banner\x10\x0f\x12\x14\n\x10module_item_null\x10\x10\x12\x15\n\x11module_share_info\x10\x11\x12\x14\n\x10module_recommend\x10\x12\x12\x17\n\x13module_stat_forward\x10\x13\x12\x0e\n\nmodule_top\x10\x14\x12\x11\n\rmodule_bottom\x10\x15*U\n\nDynUriType\x12\x15\n\x11\x64yn_uri_type_none\x10\x00\x12\x17\n\x13\x64yn_uri_type_direct\x10\x01\x12\x17\n\x13\x64yn_uri_type_suffix\x10\x02*\xb8\x02\n\x0b\x44ynamicType\x12\x0c\n\x08\x64yn_none\x10\x00\x12\x0b\n\x07\x66orward\x10\x01\x12\x06\n\x02\x61v\x10\x02\x12\x07\n\x03pgc\x10\x03\x12\x0b\n\x07\x63ourses\x10\x04\x12\x08\n\x04\x66old\x10\x05\x12\x08\n\x04word\x10\x06\x12\x08\n\x04\x64raw\x10\x07\x12\x0b\n\x07\x61rticle\x10\x08\x12\t\n\x05music\x10\t\x12\x11\n\rcommon_square\x10\n\x12\x13\n\x0f\x63ommon_vertical\x10\x0b\x12\x08\n\x04live\x10\x0c\x12\r\n\tmedialist\x10\r\x12\x12\n\x0e\x63ourses_season\x10\x0e\x12\x06\n\x02\x61\x64\x10\x0f\x12\n\n\x06\x61pplet\x10\x10\x12\x10\n\x0csubscription\x10\x11\x12\r\n\tlive_rcmd\x10\x12\x12\n\n\x06\x62\x61nner\x10\x13\x12\x0e\n\nugc_season\x10\x14\x12\x14\n\x10subscription_new\x10\x15*B\n\tEmojiType\x12\x0e\n\nemoji_none\x10\x00\x12\r\n\temoji_old\x10\x01\x12\r\n\temoji_new\x10\x02\x12\x07\n\x03vip\x10\x03*\x17\n\x0b\x45spaceStyle\x12\x08\n\x04moba\x10\x00*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZore\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*.\n\nFollowType\x12\x11\n\rft_not_follow\x10\x00\x12\r\n\tft_follow\x10\x01*9\n\x12HighlightTextStyle\x12\x0e\n\nstyle_none\x10\x00\x12\x13\n\x0fstyle_highlight\x10\x01*:\n\nImageStyle\x12\x16\n\x12\x61\x64\x64_style_vertical\x10\x00\x12\x14\n\x10\x61\x64\x64_style_square\x10\x01*<\n\tLiveState\x12\r\n\tlive_none\x10\x00\x12\r\n\tlive_live\x10\x01\x12\x11\n\rlive_rotation\x10\x02*<\n\rLocalIconType\x12\x16\n\x12local_icon_comment\x10\x00\x12\x13\n\x0flocal_icon_like\x10\x01*b\n\x10MdlDynCommonType\x12\x17\n\x13mdl_dyn_common_none\x10\x00\x12\x19\n\x15mdl_dyn_common_square\x10\x01\x12\x1a\n\x16mdl_dyn_common_vertica\x10\x02*\xa0\x01\n\x11MdlDynDrawTagType\x12\x15\n\x11mdl_draw_tag_none\x10\x00\x12\x17\n\x13mdl_draw_tag_common\x10\x01\x12\x16\n\x12mdl_draw_tag_goods\x10\x02\x12\x15\n\x11mdl_draw_tag_user\x10\x03\x12\x16\n\x12mdl_draw_tag_topic\x10\x04\x12\x14\n\x10mdl_draw_tag_lbs\x10\x05*\x97\x01\n\x1aMdlDynSubscriptionNewStyle\x12\'\n#mdl_dyn_subscription_new_style_nont\x10\x00\x12\'\n#mdl_dyn_subscription_new_style_live\x10\x01\x12\'\n#mdl_dyn_subscription_new_style_draw\x10\x02*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xad\x01\n\x15ModuleAuthorBadgeType\x12!\n\x1dmodule_author_badge_type_none\x10\x00\x12\'\n#module_author_badge_type_threePoint\x10\x01\x12#\n\x1fmodule_author_badge_type_button\x10\x02\x12#\n\x1fmodule_author_badge_type_weight\x10\x03*L\n\x10ModuleBannerType\x12\x1b\n\x17module_banner_type_none\x10\x00\x12\x1b\n\x17module_banner_type_user\x10\x01*\xf1\x02\n\x11ModuleDynamicType\x12\x13\n\x0fmdl_dyn_archive\x10\x00\x12\x0f\n\x0bmdl_dyn_pgc\x10\x01\x12\x17\n\x13mdl_dyn_cour_season\x10\x02\x12\x16\n\x12mdl_dyn_cour_batch\x10\x03\x12\x13\n\x0fmdl_dyn_forward\x10\x04\x12\x10\n\x0cmdl_dyn_draw\x10\x05\x12\x13\n\x0fmdl_dyn_article\x10\x06\x12\x11\n\rmdl_dyn_music\x10\x07\x12\x12\n\x0emdl_dyn_common\x10\x08\x12\x10\n\x0cmdl_dyn_live\x10\t\x12\x15\n\x11mdl_dyn_medialist\x10\n\x12\x12\n\x0emdl_dyn_applet\x10\x0b\x12\x18\n\x14mdl_dyn_subscription\x10\x0c\x12\x15\n\x11mdl_dyn_live_rcmd\x10\r\x12\x16\n\x12mdl_dyn_ugc_season\x10\x0e\x12\x1c\n\x18mdl_dyn_subscription_new\x10\x0f*/\n\x07Refresh\x12\x0f\n\x0brefresh_new\x10\x00\x12\x13\n\x0frefresh_history\x10\x01*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*3\n\x0bReserveType\x12\x10\n\x0creserve_none\x10\x00\x12\x12\n\x0ereserve_recall\x10\x01*C\n\x19ThreePointAttentionStatus\x12\x14\n\x10tp_not_attention\x10\x00\x12\x10\n\x0ctp_attention\x10\x01*\x93\x01\n\x0eThreePointType\x12\x0b\n\x07tp_none\x10\x00\x12\x0e\n\nbackground\x10\x01\x12\r\n\tauto_play\x10\x02\x12\t\n\x05share\x10\x03\x12\x08\n\x04wait\x10\x04\x12\r\n\tattention\x10\x05\x12\n\n\x06report\x10\x06\x12\n\n\x06\x64\x65lete\x10\x07\x12\x0b\n\x07\x64islike\x10\x08\x12\x0c\n\x08\x66\x61vorite\x10\t*\"\n\tThumbType\x12\n\n\x06\x63\x61ncel\x10\x00\x12\t\n\x05thumb\x10\x01*\x96\x01\n\x0cUserItemType\x12\x17\n\x13user_item_type_none\x10\x00\x12\x17\n\x13user_item_type_live\x10\x01\x12\x1e\n\x1auser_item_type_live_custom\x10\x02\x12\x19\n\x15user_item_type_normal\x10\x03\x12\x19\n\x15user_item_type_extend\x10\x04*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*T\n\tVideoType\x12\x16\n\x12video_type_general\x10\x00\x12\x16\n\x12video_type_dynamic\x10\x01\x12\x17\n\x13video_type_playback\x10\x02*\'\n\nVoteStatus\x12\n\n\x06normal\x10\x00\x12\r\n\tanonymous\x10\x01*B\n\nWeightType\x12\x0f\n\x0bweight_none\x10\x00\x12\x12\n\x0eweight_dislike\x10\x01\x12\x0f\n\x0bweight_jump\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dynamic.gw.gateway_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDBUTTONBGSTYLE']._serialized_start=28369
  _globals['_ADDBUTTONBGSTYLE']._serialized_end=28419
  _globals['_ADDBUTTONTYPE']._serialized_start=28421
  _globals['_ADDBUTTONTYPE']._serialized_end=28477
  _globals['_ADDITIONVOTESTATE']._serialized_start=28479
  _globals['_ADDITIONVOTESTATE']._serialized_end=28589
  _globals['_ADDITIONVOTETYPE']._serialized_start=28592
  _globals['_ADDITIONVOTETYPE']._serialized_end=28728
  _globals['_ADDITIONALBUTTONCLICKTYPE']._serialized_start=28730
  _globals['_ADDITIONALBUTTONCLICKTYPE']._serialized_end=28787
  _globals['_ADDITIONALBUTTONSTATUS']._serialized_start=28789
  _globals['_ADDITIONALBUTTONSTATUS']._serialized_end=28847
  _globals['_ADDITIONALTYPE']._serialized_start=28850
  _globals['_ADDITIONALTYPE']._serialized_end=29111
  _globals['_DESCTYPE']._serialized_start=29114
  _globals['_DESCTYPE']._serialized_end=29491
  _globals['_DISABLESTATE']._serialized_start=29493
  _globals['_DISABLESTATE']._serialized_end=29532
  _globals['_DYNEXTENDTYPE']._serialized_start=29535
  _globals['_DYNEXTENDTYPE']._serialized_end=29764
  _globals['_DYNMODULETYPE']._serialized_start=29767
  _globals['_DYNMODULETYPE']._serialized_end=30224
  _globals['_DYNURITYPE']._serialized_start=30226
  _globals['_DYNURITYPE']._serialized_end=30311
  _globals['_DYNAMICTYPE']._serialized_start=30314
  _globals['_DYNAMICTYPE']._serialized_end=30626
  _globals['_EMOJITYPE']._serialized_start=30628
  _globals['_EMOJITYPE']._serialized_end=30694
  _globals['_ESPACESTYLE']._serialized_start=30696
  _globals['_ESPACESTYLE']._serialized_end=30719
  _globals['_FOLDTYPE']._serialized_start=30721
  _globals['_FOLDTYPE']._serialized_end=30830
  _globals['_FOLLOWTYPE']._serialized_start=30832
  _globals['_FOLLOWTYPE']._serialized_end=30878
  _globals['_HIGHLIGHTTEXTSTYLE']._serialized_start=30880
  _globals['_HIGHLIGHTTEXTSTYLE']._serialized_end=30937
  _globals['_IMAGESTYLE']._serialized_start=30939
  _globals['_IMAGESTYLE']._serialized_end=30997
  _globals['_LIVESTATE']._serialized_start=30999
  _globals['_LIVESTATE']._serialized_end=31059
  _globals['_LOCALICONTYPE']._serialized_start=31061
  _globals['_LOCALICONTYPE']._serialized_end=31121
  _globals['_MDLDYNCOMMONTYPE']._serialized_start=31123
  _globals['_MDLDYNCOMMONTYPE']._serialized_end=31221
  _globals['_MDLDYNDRAWTAGTYPE']._serialized_start=31224
  _globals['_MDLDYNDRAWTAGTYPE']._serialized_end=31384
  _globals['_MDLDYNSUBSCRIPTIONNEWSTYLE']._serialized_start=31387
  _globals['_MDLDYNSUBSCRIPTIONNEWSTYLE']._serialized_end=31538
  _globals['_MEDIATYPE']._serialized_start=31540
  _globals['_MEDIATYPE']._serialized_end=31643
  _globals['_MODULEAUTHORBADGETYPE']._serialized_start=31646
  _globals['_MODULEAUTHORBADGETYPE']._serialized_end=31819
  _globals['_MODULEBANNERTYPE']._serialized_start=31821
  _globals['_MODULEBANNERTYPE']._serialized_end=31897
  _globals['_MODULEDYNAMICTYPE']._serialized_start=31900
  _globals['_MODULEDYNAMICTYPE']._serialized_end=32269
  _globals['_REFRESH']._serialized_start=32271
  _globals['_REFRESH']._serialized_end=32318
  _globals['_RELATIONSTATUS']._serialized_start=32321
  _globals['_RELATIONSTATUS']._serialized_end=32516
  _globals['_RESERVETYPE']._serialized_start=32518
  _globals['_RESERVETYPE']._serialized_end=32569
  _globals['_THREEPOINTATTENTIONSTATUS']._serialized_start=32571
  _globals['_THREEPOINTATTENTIONSTATUS']._serialized_end=32638
  _globals['_THREEPOINTTYPE']._serialized_start=32641
  _globals['_THREEPOINTTYPE']._serialized_end=32788
  _globals['_THUMBTYPE']._serialized_start=32790
  _globals['_THUMBTYPE']._serialized_end=32824
  _globals['_USERITEMTYPE']._serialized_start=32827
  _globals['_USERITEMTYPE']._serialized_end=32977
  _globals['_VIDEOSUBTYPE']._serialized_start=32980
  _globals['_VIDEOSUBTYPE']._serialized_end=33145
  _globals['_VIDEOTYPE']._serialized_start=33147
  _globals['_VIDEOTYPE']._serialized_end=33231
  _globals['_VOTESTATUS']._serialized_start=33233
  _globals['_VOTESTATUS']._serialized_end=33272
  _globals['_WEIGHTTYPE']._serialized_start=33274
  _globals['_WEIGHTTYPE']._serialized_end=33340
  _globals['_ADPARAM']._serialized_start=90
  _globals['_ADPARAM']._serialized_end=137
  _globals['_ADDITIONCOMMON']._serialized_start=140
  _globals['_ADDITIONCOMMON']._serialized_end=429
  _globals['_ADDITIONESPORT']._serialized_start=432
  _globals['_ADDITIONESPORT']._serialized_end=621
  _globals['_ADDITIONESPORTMOBA']._serialized_start=624
  _globals['_ADDITIONESPORTMOBA']._serialized_end=949
  _globals['_ADDITIONESPORTMOBASTATUS']._serialized_start=952
  _globals['_ADDITIONESPORTMOBASTATUS']._serialized_end=1143
  _globals['_ADDITIONESPORTMOBASTATUSDESC']._serialized_start=1145
  _globals['_ADDITIONESPORTMOBASTATUSDESC']._serialized_end=1226
  _globals['_ADDITIONGOODS']._serialized_start=1229
  _globals['_ADDITIONGOODS']._serialized_end=1388
  _globals['_ADDITIONUP']._serialized_start=1391
  _globals['_ADDITIONUP']._serialized_end=1679
  _globals['_ADDITIONUGC']._serialized_start=1682
  _globals['_ADDITIONUGC']._serialized_end=1855
  _globals['_ADDITIONVOTE']._serialized_start=1857
  _globals['_ADDITIONVOTE']._serialized_end=1955
  _globals['_ADDITIONVOTE2']._serialized_start=1958
  _globals['_ADDITIONVOTE2']._serialized_end=2610
  _globals['_ADDITIONVOTEDEFAULE']._serialized_start=2612
  _globals['_ADDITIONVOTEDEFAULE']._serialized_end=2648
  _globals['_ADDITIONVOTEPIC']._serialized_start=2650
  _globals['_ADDITIONVOTEPIC']._serialized_end=2728
  _globals['_ADDITIONVOTEPICITEM']._serialized_start=2731
  _globals['_ADDITIONVOTEPICITEM']._serialized_end=2871
  _globals['_ADDITIONVOTEWORD']._serialized_start=2873
  _globals['_ADDITIONVOTEWORD']._serialized_end=2953
  _globals['_ADDITIONVOTEWORDITEM']._serialized_start=2955
  _globals['_ADDITIONVOTEWORDITEM']._serialized_end=3081
  _globals['_ADDITIONALACTSKIN']._serialized_start=3083
  _globals['_ADDITIONALACTSKIN']._serialized_end=3156
  _globals['_ADDITIONALBUTTON']._serialized_start=3159
  _globals['_ADDITIONALBUTTON']._serialized_end=3588
  _globals['_ADDITIONALBUTTONINTERACTIVE']._serialized_start=3590
  _globals['_ADDITIONALBUTTONINTERACTIVE']._serialized_end=3682
  _globals['_ADDITIONALBUTTONSTYLE']._serialized_start=3685
  _globals['_ADDITIONALBUTTONSTYLE']._serialized_end=3946
  _globals['_ADDITIONALPGC']._serialized_start=3949
  _globals['_ADDITIONALPGC']._serialized_end=4218
  _globals['_CARDVIDEODYNLIST']._serialized_start=4221
  _globals['_CARDVIDEODYNLIST']._serialized_end=4379
  _globals['_CARDVIDEOFOLLOWLIST']._serialized_start=4381
  _globals['_CARDVIDEOFOLLOWLIST']._serialized_end=4481
  _globals['_CARDVIDEOUPLIST']._serialized_start=4484
  _globals['_CARDVIDEOUPLIST']._serialized_end=4772
  _globals['_CMTSHOWITEM']._serialized_start=4774
  _globals['_CMTSHOWITEM']._serialized_end=4845
  _globals['_DECOCARDFAN']._serialized_start=4847
  _globals['_DECOCARDFAN']._serialized_end=4927
  _globals['_DECORATECARD']._serialized_start=4929
  _globals['_DECORATECARD']._serialized_end=5043
  _globals['_DESCRIPTION']._serialized_start=5046
  _globals['_DESCRIPTION']._serialized_end=5340
  _globals['_DIMENSION']._serialized_start=5342
  _globals['_DIMENSION']._serialized_end=5400
  _globals['_DYNADDITIONCOMMONFOLLOWREPLY']._serialized_start=5402
  _globals['_DYNADDITIONCOMMONFOLLOWREPLY']._serialized_end=5498
  _globals['_DYNADDITIONCOMMONFOLLOWREQ']._serialized_start=5501
  _globals['_DYNADDITIONCOMMONFOLLOWREQ']._serialized_end=5630
  _globals['_DYNALLPERSONALREPLY']._serialized_start=5633
  _globals['_DYNALLPERSONALREPLY']._serialized_end=5816
  _globals['_DYNALLPERSONALREQ']._serialized_start=5819
  _globals['_DYNALLPERSONALREQ']._serialized_end=6081
  _globals['_DYNALLREPLY']._serialized_start=6084
  _globals['_DYNALLREPLY']._serialized_end=6329
  _globals['_DYNALLREQ']._serialized_start=6332
  _globals['_DYNALLREQ']._serialized_end=6773
  _globals['_DYNALLUPDOFFSETREQ']._serialized_start=6775
  _globals['_DYNALLUPDOFFSETREQ']._serialized_end=6853
  _globals['_DYNDETAILREPLY']._serialized_start=6855
  _globals['_DYNDETAILREPLY']._serialized_end=6924
  _globals['_DYNDETAILSREQ']._serialized_start=6927
  _globals['_DYNDETAILSREQ']._serialized_end=7105
  _globals['_DYNFAKECARDREPLY']._serialized_start=7107
  _globals['_DYNFAKECARDREPLY']._serialized_end=7178
  _globals['_DYNFAKECARDREQ']._serialized_start=7180
  _globals['_DYNFAKECARDREQ']._serialized_end=7213
  _globals['_DYNMIXUPLISTVIEWMOREREPLY']._serialized_start=7216
  _globals['_DYNMIXUPLISTVIEWMOREREPLY']._serialized_end=7441
  _globals['_DYNMIXUPLISTVIEWMOREREQ']._serialized_start=7443
  _globals['_DYNMIXUPLISTVIEWMOREREQ']._serialized_end=7487
  _globals['_DYNRCMDUPEXCHANGEREPLY']._serialized_start=7489
  _globals['_DYNRCMDUPEXCHANGEREPLY']._serialized_end=7567
  _globals['_DYNRCMDUPEXCHANGEREQ']._serialized_start=7569
  _globals['_DYNRCMDUPEXCHANGEREQ']._serialized_end=7637
  _globals['_DYNTHUMBREQ']._serialized_start=7639
  _globals['_DYNTHUMBREQ']._serialized_end=7763
  _globals['_DYNVIDEOPERSONALREPLY']._serialized_start=7766
  _globals['_DYNVIDEOPERSONALREPLY']._serialized_end=7951
  _globals['_DYNVIDEOPERSONALREQ']._serialized_start=7954
  _globals['_DYNVIDEOPERSONALREQ']._serialized_end=8218
  _globals['_DYNVIDEOREPLY']._serialized_start=8221
  _globals['_DYNVIDEOREPLY']._serialized_end=8442
  _globals['_DYNVIDEOREQ']._serialized_start=8445
  _globals['_DYNVIDEOREQ']._serialized_end=8751
  _globals['_DYNVIDEOUPDOFFSETREQ']._serialized_start=8753
  _globals['_DYNVIDEOUPDOFFSETREQ']._serialized_end=8833
  _globals['_DYNVOTEREPLY']._serialized_start=8835
  _globals['_DYNVOTEREPLY']._serialized_end=8919
  _globals['_DYNVOTEREQ']._serialized_start=8922
  _globals['_DYNVOTEREQ']._serialized_end=9055
  _globals['_DYNAMICITEM']._serialized_start=9058
  _globals['_DYNAMICITEM']._serialized_end=9306
  _globals['_DYNAMICLIST']._serialized_start=9309
  _globals['_DYNAMICLIST']._serialized_end=9462
  _globals['_EXTINFOCOMMON']._serialized_start=9465
  _globals['_EXTINFOCOMMON']._serialized_end=9692
  _globals['_EXTINFOGAME']._serialized_start=9694
  _globals['_EXTINFOGAME']._serialized_end=9749
  _globals['_EXTINFOHOT']._serialized_start=9751
  _globals['_EXTINFOHOT']._serialized_end=9805
  _globals['_EXTINFOLBS']._serialized_start=9807
  _globals['_EXTINFOLBS']._serialized_end=9879
  _globals['_EXTINFOOGV']._serialized_start=9881
  _globals['_EXTINFOOGV']._serialized_end=9946
  _globals['_EXTINFOTOPIC']._serialized_start=9948
  _globals['_EXTINFOTOPIC']._serialized_end=10004
  _globals['_EXTEND']._serialized_start=10007
  _globals['_EXTEND']._serialized_end=10543
  _globals['_EXTENDREPLY']._serialized_start=10545
  _globals['_EXTENDREPLY']._serialized_end=10631
  _globals['_EXTENDREPLYPARAM']._serialized_start=10633
  _globals['_EXTENDREPLYPARAM']._serialized_end=10679
  _globals['_FOLLOWLISTITEM']._serialized_start=10682
  _globals['_FOLLOWLISTITEM']._serialized_end=10841
  _globals['_GOODSITEM']._serialized_start=10844
  _globals['_GOODSITEM']._serialized_end=11102
  _globals['_HIGHLIGHTTEXT']._serialized_start=11104
  _globals['_HIGHLIGHTTEXT']._serialized_end=11199
  _globals['_INFOOGV']._serialized_start=11201
  _globals['_INFOOGV']._serialized_end=11272
  _globals['_INTERACTIONITEM']._serialized_start=11275
  _globals['_INTERACTIONITEM']._serialized_end=11459
  _globals['_LIKEANIMATION']._serialized_start=11461
  _globals['_LIKEANIMATION']._serialized_end=11540
  _globals['_LIKEINFO']._serialized_start=11542
  _globals['_LIKEINFO']._serialized_end=11629
  _globals['_LIKEUSER']._serialized_start=11631
  _globals['_LIKEUSER']._serialized_end=11682
  _globals['_LIVEINFO']._serialized_start=11684
  _globals['_LIVEINFO']._serialized_end=11783
  _globals['_MATCHTEAM']._serialized_start=11785
  _globals['_MATCHTEAM']._serialized_end=11873
  _globals['_MDLDYNAPPLET']._serialized_start=11876
  _globals['_MDLDYNAPPLET']._serialized_end=12015
  _globals['_MDLDYNARCHIVE']._serialized_start=12018
  _globals['_MDLDYNARCHIVE']._serialized_end=12757
  _globals['_MDLDYNARTICLE']._serialized_start=12759
  _globals['_MDLDYNARTICLE']._serialized_end=12879
  _globals['_MDLDYNCOMMON']._serialized_start=12882
  _globals['_MDLDYNCOMMON']._serialized_end=13128
  _globals['_MDLDYNCOURBATCH']._serialized_start=13131
  _globals['_MDLDYNCOURBATCH']._serialized_end=13295
  _globals['_MDLDYNCOURSEASON']._serialized_start=13298
  _globals['_MDLDYNCOURSEASON']._serialized_end=13461
  _globals['_MDLDYNDRAW']._serialized_start=13463
  _globals['_MDLDYNDRAW']._serialized_end=13557
  _globals['_MDLDYNDRAWITEM']._serialized_start=13560
  _globals['_MDLDYNDRAWITEM']._serialized_end=13689
  _globals['_MDLDYNDRAWTAG']._serialized_start=13692
  _globals['_MDLDYNDRAWTAG']._serialized_end=13825
  _globals['_MDLDYNDRAWTAGITEM']._serialized_start=13828
  _globals['_MDLDYNDRAWTAGITEM']._serialized_end=14009
  _globals['_MDLDYNFORWARD']._serialized_start=14011
  _globals['_MDLDYNFORWARD']._serialized_end=14094
  _globals['_MDLDYNLIVE']._serialized_start=14097
  _globals['_MDLDYNLIVE']._serialized_end=14378
  _globals['_MDLDYNLIVERCMD']._serialized_start=14380
  _globals['_MDLDYNLIVERCMD']._serialized_end=14474
  _globals['_MDLDYNMEDIALIST']._serialized_start=14477
  _globals['_MDLDYNMEDIALIST']._serialized_end=14641
  _globals['_MDLDYNMUSIC']._serialized_start=14643
  _globals['_MDLDYNMUSIC']._serialized_end=14757
  _globals['_MDLDYNPGC']._serialized_start=14760
  _globals['_MDLDYNPGC']._serialized_end=15406
  _globals['_MDLDYNSUBSCRIPTION']._serialized_start=15409
  _globals['_MDLDYNSUBSCRIPTION']._serialized_end=15584
  _globals['_MDLDYNSUBSCRIPTIONNEW']._serialized_start=15587
  _globals['_MDLDYNSUBSCRIPTIONNEW']._serialized_end=15828
  _globals['_MDLDYNUGCSEASON']._serialized_start=15831
  _globals['_MDLDYNUGCSEASON']._serialized_end=16159
  _globals['_MIXUPLISTITEM']._serialized_start=16162
  _globals['_MIXUPLISTITEM']._serialized_end=16493
  _globals['_MIXUPLISTLIVEITEM']._serialized_start=16495
  _globals['_MIXUPLISTLIVEITEM']._serialized_end=16560
  _globals['_MODULE']._serialized_start=16563
  _globals['_MODULE']._serialized_end=17987
  _globals['_MODULEAD']._serialized_start=17989
  _globals['_MODULEAD']._serialized_end=18108
  _globals['_MODULEADDITIONAL']._serialized_start=18111
  _globals['_MODULEADDITIONAL']._serialized_end=18660
  _globals['_MODULEAUTHOR']._serialized_start=18663
  _globals['_MODULEAUTHOR']._serialized_end=19165
  _globals['_MODULEAUTHORBADGEBUTTON']._serialized_start=19167
  _globals['_MODULEAUTHORBADGEBUTTON']._serialized_end=19248
  _globals['_MODULEAUTHORFORWARD']._serialized_start=19251
  _globals['_MODULEAUTHORFORWARD']._serialized_end=19543
  _globals['_MODULEAUTHORFORWARDTITLE']._serialized_start=19545
  _globals['_MODULEAUTHORFORWARDTITLE']._serialized_end=19598
  _globals['_MODULEBANNER']._serialized_start=19601
  _globals['_MODULEBANNER']._serialized_end=19800
  _globals['_MODULEBANNERUSER']._serialized_start=19802
  _globals['_MODULEBANNERUSER']._serialized_end=19882
  _globals['_MODULEBANNERUSERITEM']._serialized_start=19885
  _globals['_MODULEBANNERUSERITEM']._serialized_end=20201
  _globals['_MODULEBUTTOM']._serialized_start=20203
  _globals['_MODULEBUTTOM']._serialized_end=20276
  _globals['_MODULECOMMENT']._serialized_start=20278
  _globals['_MODULECOMMENT']._serialized_end=20353
  _globals['_MODULEDESC']._serialized_start=20355
  _globals['_MODULEDESC']._serialized_end=20452
  _globals['_MODULEDESCGOODS']._serialized_start=20455
  _globals['_MODULEDESCGOODS']._serialized_end=20640
  _globals['_MODULEDISPUTE']._serialized_start=20642
  _globals['_MODULEDISPUTE']._serialized_end=20699
  _globals['_MODULEDYNAMIC']._serialized_start=20702
  _globals['_MODULEDYNAMIC']._serialized_end=21845
  _globals['_MODULEEXTEND']._serialized_start=21847
  _globals['_MODULEEXTEND']._serialized_end=21934
  _globals['_MODULEEXTENDITEM']._serialized_start=21937
  _globals['_MODULEEXTENDITEM']._serialized_end=22404
  _globals['_MODULEFOLD']._serialized_start=22407
  _globals['_MODULEFOLD']._serialized_end=22562
  _globals['_MODULEINTERACTION']._serialized_start=22564
  _globals['_MODULEINTERACTION']._serialized_end=22652
  _globals['_MODULEITEMNULL']._serialized_start=22654
  _globals['_MODULEITEMNULL']._serialized_end=22698
  _globals['_MODULELIKEUSER']._serialized_start=22700
  _globals['_MODULELIKEUSER']._serialized_end=22794
  _globals['_MODULERECOMMEND']._serialized_start=22797
  _globals['_MODULERECOMMEND']._serialized_end=22931
  _globals['_MODULESHAREINFO']._serialized_start=22934
  _globals['_MODULESHAREINFO']._serialized_end=23078
  _globals['_MODULESTAT']._serialized_start=23081
  _globals['_MODULESTAT']._serialized_end=23302
  _globals['_MODULETOP']._serialized_start=23304
  _globals['_MODULETOP']._serialized_end=23374
  _globals['_NAMEPLATE']._serialized_start=23376
  _globals['_NAMEPLATE']._serialized_end=23484
  _globals['_NEWEP']._serialized_start=23486
  _globals['_NEWEP']._serialized_end=23540
  _globals['_NOREPLY']._serialized_start=23542
  _globals['_NOREPLY']._serialized_end=23551
  _globals['_NOREQ']._serialized_start=23553
  _globals['_NOREQ']._serialized_end=23560
  _globals['_OFFICIALVERIFY']._serialized_start=23562
  _globals['_OFFICIALVERIFY']._serialized_end=23624
  _globals['_PGCSEASON']._serialized_start=23626
  _globals['_PGCSEASON']._serialized_end=23685
  _globals['_PLAYERARGS']._serialized_start=23687
  _globals['_PLAYERARGS']._serialized_end=23761
  _globals['_PLAYURLPARAM']._serialized_start=23763
  _globals['_PLAYURLPARAM']._serialized_end=23854
  _globals['_RCMDUPSPARAM']._serialized_start=23856
  _globals['_RCMDUPSPARAM']._serialized_end=23890
  _globals['_RELATION']._serialized_start=23892
  _globals['_RELATION']._serialized_end=24015
  _globals['_SHARECHANNEL']._serialized_start=24017
  _globals['_SHARECHANNEL']._serialized_end=24077
  _globals['_SORTTYPE']._serialized_start=24079
  _globals['_SORTTYPE']._serialized_end=24132
  _globals['_THREEPOINTATTENTION']._serialized_start=24135
  _globals['_THREEPOINTATTENTION']._serialized_end=24329
  _globals['_THREEPOINTAUTOPLAY']._serialized_start=24332
  _globals['_THREEPOINTAUTOPLAY']._serialized_end=24558
  _globals['_THREEPOINTDEFAULT']._serialized_start=24560
  _globals['_THREEPOINTDEFAULT']._serialized_end=24633
  _globals['_THREEPOINTDISLIKE']._serialized_start=24635
  _globals['_THREEPOINTDISLIKE']._serialized_end=24683
  _globals['_THREEPOINTFAVORITE']._serialized_start=24685
  _globals['_THREEPOINTFAVORITE']._serialized_end=24811
  _globals['_THREEPOINTITEM']._serialized_start=24814
  _globals['_THREEPOINTITEM']._serialized_end=25343
  _globals['_THREEPOINTSHARE']._serialized_start=25346
  _globals['_THREEPOINTSHARE']._serialized_end=25481
  _globals['_THREEPOINTSHARECHANNEL']._serialized_start=25483
  _globals['_THREEPOINTSHARECHANNEL']._serialized_end=25536
  _globals['_THREEPOINTWAIT']._serialized_start=25538
  _globals['_THREEPOINTWAIT']._serialized_end=25664
  _globals['_TOPICBUTTON']._serialized_start=25666
  _globals['_TOPICBUTTON']._serialized_end=25726
  _globals['_TOPICLIST']._serialized_start=25729
  _globals['_TOPICLIST']._serialized_end=25940
  _globals['_TOPICLISTITEM']._serialized_start=25942
  _globals['_TOPICLISTITEM']._serialized_end=26055
  _globals['_UNFOLLOW']._serialized_start=26057
  _globals['_UNFOLLOW']._serialized_end=26157
  _globals['_UNFOLLOWUSERITEM']._serialized_start=26160
  _globals['_UNFOLLOWUSERITEM']._serialized_end=26506
  _globals['_UPLISTITEM']._serialized_start=26509
  _globals['_UPLISTITEM']._serialized_end=26923
  _globals['_UPLISTMORELABEL']._serialized_start=26925
  _globals['_UPLISTMORELABEL']._serialized_end=26970
  _globals['_USERINFO']._serialized_start=26973
  _globals['_USERINFO']._serialized_end=27307
  _globals['_USERITEMSTYLE']._serialized_start=27309
  _globals['_USERITEMSTYLE']._serialized_end=27435
  _globals['_USERPENDANT']._serialized_start=27437
  _globals['_USERPENDANT']._serialized_end=27508
  _globals['_VIDEOBADGE']._serialized_start=27511
  _globals['_VIDEOBADGE']._serialized_end=27735
  _globals['_VIPINFO']._serialized_start=27738
  _globals['_VIPINFO']._serialized_end=27916
  _globals['_VIPLABEL']._serialized_start=27918
  _globals['_VIPLABEL']._serialized_end=27977
  _globals['_WEIGHT']._serialized_start=27979
  _globals['_WEIGHT']._serialized_end=28069
  _globals['_WEIGHTBUTTON']._serialized_start=28071
  _globals['_WEIGHTBUTTON']._serialized_end=28118
  _globals['_WEIGHTDISLIKE']._serialized_start=28120
  _globals['_WEIGHTDISLIKE']._serialized_end=28174
  _globals['_WEIGHTITEM']._serialized_start=28177
  _globals['_WEIGHTITEM']._serialized_end=28367
# @@protoc_insertion_point(module_scope)
